@@ -4,4 +4,4 @@ from django.template.defaultfilters import register
 
 @register.filter
 def demo(value):
-    return 'demo-' + value
+    return value + 'demo'
