@@ -23,10 +23,18 @@ def demo_piechart(request):
     extra_serie = {"tooltip": {"y_start": "", "y_end": " cal"}}
     chartdata = {'x': xdata, 'y1': ydata, 'extra1': extra_serie}
     charttype = "pieChart"
+    chartcontainer = 'piechart_container'  # container name
 
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': False,
+            'x_axis_format': '',
+            'tag_script_js': False,
+            'jquery_on_ready': False,
+        }
     }
     return render_to_response('piechart.html', data)
 
@@ -36,7 +44,7 @@ def demo_linechart(request):
     lineChart page
     """
     start_time = int(time.mktime(datetime.datetime(2012, 6, 1).timetuple()) * 1000)
-    nb_element = 100
+    nb_element = 150
     xdata = range(nb_element)
     xdata = map(lambda x: start_time + x * 1000000000, xdata)
     ydata = [i + random.randint(1, 10) for i in range(nb_element)]
@@ -50,10 +58,17 @@ def demo_linechart(request):
                  'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie}
 
     charttype = "lineChart"
+    chartcontainer = 'linechart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
-        'date_tag' : True,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': True,
+            'x_axis_format': '%d %b %Y %H',
+            'tag_script_js': False,
+            'jquery_on_ready': False,
+        }
     }
     return render_to_response('linechart.html', data)
 
@@ -65,14 +80,22 @@ def demo_linechart_without_date(request):
     extra_serie = {}
     xdata = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
     ydata = [3, 5, 7, 8, 3, 5, 3, 5, 7, 6, 3, 1]
-    chartdata = {'x': xdata,
-                 'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
-                }
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
+    }
     charttype = "lineChart"
+    chartcontainer = 'linechart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
-        'date_tag' : False,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': False,
+            'x_axis_format': '',
+            'tag_script_js': False,
+            'jquery_on_ready': False,
+        }
     }
     return render_to_response('linechart.html', data)
 
@@ -103,9 +126,17 @@ def demo_linewithfocuschart(request):
         'name4': 'series 4', 'y4': ydata4, 'extra4': extra_serie
     }
     charttype = "lineWithFocusChart"
+    chartcontainer = 'linewithfocuschart_container'  # container name
     data = {
         'charttype': charttype,
-        'chartdata': chartdata
+        'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': True,
+            'x_axis_format': '%d %b %Y %H',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        }
     }
     return render_to_response('linewithfocuschart.html', data)
 
@@ -149,10 +180,27 @@ def demo_multibarchart(request):
     }
 
     charttype = "multiBarChart"
+    chartcontainer = 'multibarchart_container'  # container name
+    chartcontainer_with_date = 'date_multibarchart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
-        'date_chartdata': date_chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': False,
+            'x_axis_format': '',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
+        'chartdata_with_date': date_chartdata,
+        'chartcontainer_with_date': chartcontainer_with_date,
+        'extra_with_date': {
+            'name': chartcontainer_with_date,
+            'x_is_date': True,
+            'x_axis_format': '%d %b %Y',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('multibarchart.html', data)
 
@@ -176,9 +224,17 @@ def demo_stackedareachart(request):
         'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie2,
     }
     charttype = "stackedAreaChart"
+    chartcontainer = 'stackedareachart_container'  # container name
     data = {
         'charttype': charttype,
-        'chartdata': chartdata
+        'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': False,
+            'x_axis_format': '',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('stackedareachart.html', data)
 
@@ -201,9 +257,17 @@ def demo_multibarhorizontalchart(request):
     }
 
     charttype = "multiBarHorizontalChart"
+    chartcontainer = 'multibarhorizontalchart_container'  # container name
     data = {
         'charttype': charttype,
-        'chartdata': chartdata
+        'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': False,
+            'x_axis_format': '',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('multibarhorizontalchart.html', data)
 
@@ -234,9 +298,17 @@ def demo_lineplusbarchart(request):
     }
 
     charttype = "linePlusBarChart"
+    chartcontainer = 'lineplusbarchart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': True,
+            'x_axis_format': '%d %b %Y %H',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('lineplusbarchart.html', data)
 
@@ -265,9 +337,17 @@ def demo_cumulativelinechart(request):
     }
 
     charttype = "cumulativeLineChart"
+    chartcontainer = 'cumulativelinechart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': True,
+            'x_axis_format': '%d %b %Y %H',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('cumulativelinechart.html', data)
 
@@ -284,9 +364,17 @@ def demo_discretebarchart(request):
         'x': xdata, 'name1': '', 'y1': ydata, 'extra1': extra_serie1,
     }
     charttype = "discreteBarChart"
+    chartcontainer = 'discretebarchart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': False,
+            'x_axis_format': '',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('discretebarchart.html', data)
 
@@ -307,9 +395,17 @@ def demo_discretebarchart_with_date(request):
         'x': xdata, 'name1': '', 'y1': ydata, 'extra1': extra_serie1,
     }
     charttype = "discreteBarChart"
+    chartcontainer = 'discretebarchart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': True,
+            'x_axis_format': '%d-%b',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('discretebarchart_with_date.html', data)
 
@@ -337,9 +433,17 @@ def demo_scatterchart(request):
         'name3': 'series 3', 'y3': ydata3, 'kwargs3': kwargs3, 'extra3': extra_serie1
     }
     charttype = "scatterChart"
+    chartcontainer = 'scatterchart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': True,
+            'x_axis_format': '%d-%b',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('scatterchart.html', data)
 
@@ -364,9 +468,17 @@ def demo_linechart_with_ampm(request):
                  'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
                  'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie}
     charttype = "lineChart"
+    chartcontainer = 'linechart_container'  # container name
     data = {
         'charttype': charttype,
-        'chartdata': chartdata
+        'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': False,
+            'x_axis_format': 'AM_PM',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        }
     }
     return render_to_response('linechart_with_ampm.html', data)
 
@@ -399,8 +511,16 @@ def demo_lineplusbarwithfocuschart(request):
     }
 
     charttype = "linePlusBarWithFocusChart"
+    chartcontainer = 'lineplusbarwithfocuschart_container'  # container name
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
+        'chartcontainer': chartcontainer,
+        'extra': {
+            'x_is_date': True,
+            'x_axis_format': '%d %b %Y %H',
+            'tag_script_js': True,
+            'jquery_on_ready': True,
+        },
     }
     return render_to_response('lineplusbarwithfocuschart.html', data)
